@@ -4,35 +4,15 @@
 
 @authors Andrei Novikov (pyclustering@yandex.ru)
 @date 2014-2020
-@copyright GNU Public License
-
-@cond GNU_PUBLIC_LICENSE
-    PyClustering is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-    
-    PyClustering is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-    
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-@endcond
+@copyright BSD-3-Clause
 
 """
 
 import itertools
 import math
-import warnings
 
-try:
-    import matplotlib.pyplot as plt
-    import matplotlib.gridspec as gridspec
-except Exception:
-    warnings.warn("Impossible to import matplotlib (please, install 'matplotlib'), pyclustering's visualization "
-                  "functionality is not available.")
+import matplotlib.pyplot as plt
+import matplotlib.gridspec as gridspec
 
 from pyclustering.utils.color import color as color_list
 
@@ -555,13 +535,14 @@ class cluster_visualizer:
         """!
         @brief Set title for specified canvas.
         
-        @param[in] text (string): Title for canvas.
-        @param[in] canvas (uint): Index of canvas where title should be displayed.
+        @param[in] text (string): Title for the canvas.
+        @param[in] canvas (uint): Index of the canvas where title should be displayed.
 
         """
         
         if canvas > self.__number_canvases:
-            raise NameError('Canvas does ' + canvas + ' not exists.')
+            raise ValueError("Canvas with index '%d' does not exists (total amount of canvases: '%d')." %
+                             canvas, self.__number_canvases)
         
         self.__canvas_titles[canvas] = text
 
@@ -670,7 +651,7 @@ class cluster_visualizer:
                 ax.xaxis.set_ticklabels([])
                 ax.yaxis.set_ticklabels([])
                 
-                if (dimension == 3):
+                if dimension == 3:
                     ax.zaxis.set_ticklabels([])
             
             if self.__canvas_titles[index_canvas] is not None:
