@@ -5,37 +5,18 @@
 
 @authors Andrei Novikov (pyclustering@yandex.ru)
 @date 2014-2020
-@copyright GNU Public License
-
-@cond GNU_PUBLIC_LICENSE
-    PyClustering is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    PyClustering is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-@endcond
+@copyright BSD-3-Clause
 
 """
 
 import itertools
 import warnings
 
-try:
-    import matplotlib
-    import matplotlib.gridspec as gridspec
-    import matplotlib.pyplot as plt
-    import matplotlib.patches as patches
-    import matplotlib.animation as animation
-except Exception as error_instance:
-    warnings.warn("Impossible to import matplotlib (please, install 'matplotlib'), pyclustering's visualization "
-                  "functionality is not available (details: '%s')." % str(error_instance))
+import matplotlib
+import matplotlib.gridspec as gridspec
+import matplotlib.pyplot as plt
+import matplotlib.patches as patches
+import matplotlib.animation as animation
 
 from pyclustering.cluster import cluster_visualizer
 from pyclustering.cluster.encoder import type_encoding
@@ -248,8 +229,7 @@ class bang_animator:
         animator.animate()
     @endcode
 
-
-    """
+"""
     def __init__(self, directory, clusters):
         """!
         @brief Creates BANG animator instance.
