@@ -5,22 +5,7 @@
 
 @authors Andrei Novikov (pyclustering@yandex.ru)
 @date 2014-2020
-@copyright GNU Public License
-
-@cond GNU_PUBLIC_LICENSE
-    PyClustering is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    PyClustering is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-@endcond
+@copyright BSD-3-Clause
 
 """
 
@@ -34,17 +19,10 @@ from pyclustering.core.wrapper import ccore_library
 
 import pyclustering.core.clique_wrapper as wrapper
 
-
-try:
-    import matplotlib
-    import matplotlib.gridspec as gridspec
-    import matplotlib.pyplot as plt
-    import matplotlib.patches as patches
-    import matplotlib.animation as animation
-except Exception as error_instance:
-    import warnings
-    warnings.warn("Impossible to import matplotlib (please, install 'matplotlib'), pyclustering's visualization "
-                  "functionality is not available (details: '%s')." % str(error_instance))
+import matplotlib
+import matplotlib.gridspec as gridspec
+import matplotlib.pyplot as plt
+import matplotlib.patches as patches
 
 
 class clique_visualizer:
@@ -601,13 +579,14 @@ class clique:
                 user's target platform is supported.
 
         """
-        (self.__clusters, self.__noise, block_logical_locations, block_max_corners, block_min_corners, block_points) = \
-            wrapper.clique(self.__data, self.__amount_intervals, self.__density_threshold)
+        result = wrapper.clique(self.__data, self.__amount_intervals, self.__density_threshold)
+
+        (self.__clusters, self.__noise, block_logical_locations, max_corners, min_corners, block_points) = result
 
         amount_cells = len(block_logical_locations)
         for i in range(amount_cells):
             self.__cells.append(clique_block(block_logical_locations[i],
-                                             spatial_block(block_max_corners[i], block_min_corners[i]),
+                                             spatial_block(max_corners[i], min_corners[i]),
                                              block_points[i],
                                              True))
 
