@@ -5,35 +5,16 @@
 
 @authors Andrei Novikov (pyclustering@yandex.ru)
 @date 2014-2020
-@copyright GNU Public License
-
-@cond GNU_PUBLIC_LICENSE
-    PyClustering is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-    
-    PyClustering is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-    
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-@endcond
+@copyright BSD-3-Clause
 
 """
 
 
+import copy
 import numpy
-import warnings
 
-try:
-    import matplotlib.pyplot as plt
-    import matplotlib.animation as animation
-except Exception as error_instance:
-    warnings.warn("Impossible to import matplotlib (please, install 'matplotlib'), pyclustering's visualization "
-                  "functionality is not available (details: '%s')." % str(error_instance))
+import matplotlib.pyplot as plt
+import matplotlib.animation as animation
 
 import pyclustering.core.kmeans_wrapper as wrapper
 
@@ -356,14 +337,14 @@ class kmeans:
         self.__total_wce = 0.0
 
         self.__observer = kwargs.get('observer', None)
-        self.__metric = kwargs.get('metric', distance_metric(type_metric.EUCLIDEAN_SQUARE))
+        self.__metric = copy.copy(kwargs.get('metric', distance_metric(type_metric.EUCLIDEAN_SQUARE)))
         self.__itermax = kwargs.get('itermax', 100)
 
         if self.__metric.get_type() != type_metric.USER_DEFINED:
             self.__metric.enable_numpy_usage()
         else:
             self.__metric.disable_numpy_usage()
-        
+
         self.__ccore = ccore and self.__metric.get_type() != type_metric.USER_DEFINED
         if self.__ccore is True:
             self.__ccore = ccore_library.workable()
@@ -400,7 +381,9 @@ class kmeans:
         """
         ccore_metric = metric_wrapper.create_instance(self.__metric)
 
-        results = wrapper.kmeans(self.__pointer_data, self.__centers, self.__tolerance, self.__itermax, (self.__observer is not None), ccore_metric.get_pointer())
+        results = wrapper.kmeans(self.__pointer_data, self.__centers, self.__tolerance, self.__itermax,
+                                 (self.__observer is not None), ccore_metric.get_pointer())
+
         self.__clusters = results[0]
         self.__centers = results[1]
 
@@ -459,7 +442,7 @@ class kmeans:
             if self.__metric.get_type() != type_metric.USER_DEFINED:
                 differences[index_point] = self.__metric(nppoints[index_point], self.__centers)
             else:
-                differences[index_point] = [ self.__metric(nppoints[index_point], center) for center in self.__centers ]
+                differences[index_point] = [self.__metric(nppoints[index_point], center) for center in self.__centers]
 
         return numpy.argmin(differences, axis=1)
 
@@ -487,7 +470,7 @@ class kmeans:
 
         if isinstance(self.__centers, list):
             return self.__centers
-        
+
         return self.__centers.tolist()
 
 
@@ -567,7 +550,7 @@ class kmeans:
 
         dataset_differences = self.__calculate_dataset_difference(len(self.__clusters))
 
-        self.__total_wce = 0
+        self.__total_wce = 0.0
         for index_cluster in range(len(self.__clusters)):
             for index_point in self.__clusters[index_cluster]:
                 self.__total_wce += dataset_differences[index_cluster][index_point]
@@ -583,8 +566,8 @@ class kmeans:
             if self.__metric.get_type() != type_metric.USER_DEFINED:
                 dataset_differences[index_center] = self.__metric(self.__pointer_data, self.__centers[index_center])
             else:
-                dataset_differences[index_center] = [ self.__metric(point, self.__centers[index_center])
-                                                      for point in self.__pointer_data ]
+                dataset_differences[index_center] = [self.__metric(point, self.__centers[index_center])
+                                                     for point in self.__pointer_data]
 
         return dataset_differences
 
