@@ -4,43 +4,19 @@
 
 @authors Andrei Novikov (pyclustering@yandex.ru)
 @date 2014-2020
-@copyright GNU Public License
-
-@cond GNU_PUBLIC_LICENSE
-    PyClustering is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-    
-    PyClustering is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-    
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-@endcond
+@copyright BSD-3-Clause
 
 """
 
 import time
 import numpy
-import warnings
+
 
 from numpy import array
+from PIL import Image
 
-try:
-    from PIL import Image
-except Exception as error_instance:
-    warnings.warn("Impossible to import PIL (please, install 'PIL'), pyclustering's visualization "
-                  "functionality is partially not available (details: '%s')." % str(error_instance))
-
-try:
-    import matplotlib.pyplot as plt
-    from mpl_toolkits.mplot3d import Axes3D
-except Exception as error_instance:
-    warnings.warn("Impossible to import matplotlib (please, install 'matplotlib'), pyclustering's visualization "
-                  "functionality is not available (details: '%s')." % str(error_instance))
+import matplotlib.pyplot as plt
+from mpl_toolkits.mplot3d import Axes3D
 
 from sys import platform as _platform
 
@@ -236,7 +212,7 @@ def average_neighbor_distance(points, num_neigh):
 
 def medoid(data, indexes=None, **kwargs):
     """!
-    @brief Calculate medoid for input points using Euclidean distance.
+    @brief Calculate medoid for input points.
     
     @param[in] data (list): Set of points for that median should be calculated.
     @param[in] indexes (list): Indexes of input set of points that will be taken into account during median calculation.
